@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * $LastChangedBy: bastian $
- * $LastChangedDate: 2004-06-06 12:33:27 +0200 (Sun, 06 Jun 2004) $
- * $LastChangedRevision: 429 $
+ * $LastChangedDate: 2005-01-05 22:48:37 +0100 (Mi, 05 Jan 2005) $
+ * $LastChangedRevision: 785 $
  */
 
 #ifndef FRONTEND_H
@@ -41,7 +41,7 @@ int frontend_progress_start (int max);
 int frontend_progress_step (int step);
 int frontend_progress_stop (void);
 
-int frontend_main (int argc, char **argv);
+int frontend_main (int argc, char **argv, char **envp);
 int backend_main (bool download_only);
 
 #endif
