@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * $LastChangedBy: bastian $
- * $LastChangedDate: 2004-02-03 13:08:36 +0100 (Tue, 03 Feb 2004) $
- * $LastChangedRevision: 227 $
+ * $LastChangedDate: 2005-01-22 13:03:24 +0100 (Sa, 22 Jan 2005) $
+ * $LastChangedRevision: 810 $
  */
 
 #ifndef PACKAGES_H
@@ -27,6 +27,7 @@
 
 #include <debian-installer.h>
 
-char *package_get_local_filename (di_package *package);
+const char *package_get_local_filename (di_package *package);
+int package_extract (di_package *package);
 
 #endif
