@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * $LastChangedBy: bastian $
- * $LastChangedDate: 2004-06-06 12:33:27 +0200 (Sun, 06 Jun 2004) $
- * $LastChangedRevision: 429 $
+ * $LastChangedDate: 2005-01-05 22:48:37 +0100 (Mi, 05 Jan 2005) $
+ * $LastChangedRevision: 785 $
  */
 
 #include <config.h>
@@ -32,6 +32,7 @@
 #include <unistd.h>
 
 #include "check.h"
+#include "execute.h"
 #include "frontend.h"
 #include "download.h"
 #include "packages.h"
@@ -49,7 +50,7 @@ int decompress_file (const char *file, const char *extension)
 
   snprintf (buf, sizeof (buf), "gunzip -f %s.%s 2>&1", file, extension);
 
-  return install_execute (buf);
+  return execute (buf);
 }
 
 static inline int download_file (const char *source, const char *target, const char *message)
