@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * $LastChangedBy: bastian $
- * $LastChangedDate: 2004-06-06 12:33:27 +0200 (Sun, 06 Jun 2004) $
- * $LastChangedRevision: 429 $
+ * $LastChangedDate: 2005-01-14 22:34:27 +0100 (Fr, 14 Jan 2005) $
+ * $LastChangedRevision: 806 $
  */
 
 #include <config.h>
@@ -92,27 +92,39 @@ const log_template templates[] =
     1,
     DO_PROGRESS_INFO,
   },
-  [LOG_MESSAGE_INFO_INSTALL_DO] =
+  [LOG_MESSAGE_INFO_INSTALL_HELPER_EXECUTE] =
   {
-    "cdebootstrap/progress/info/install/do",
+    "cdebootstrap/progress/info/install/helper/execute",
     0,
     DO_PROGRESS_INFO,
   },
-  [LOG_MESSAGE_INFO_INSTALL_CONFIGURE_PACKAGE] =
+  [LOG_MESSAGE_INFO_INSTALL_HELPER_INSTALL] =
   {
-    "cdebootstrap/progress/info/install/configure_package",
+    "cdebootstrap/progress/info/install/helper/install",
     1,
     DO_PROGRESS_INFO,
   },
-  [LOG_MESSAGE_INFO_INSTALL_EXTRACT_PACKAGE] =
+  [LOG_MESSAGE_INFO_INSTALL_HELPER_REMOVE] =
   {
-    "cdebootstrap/progress/info/install/extract_file",
+    "cdebootstrap/progress/info/install/helper/remove",
     1,
     DO_PROGRESS_INFO,
   },
-  [LOG_MESSAGE_INFO_INSTALL_UNPACK_PACKAGE] =
+  [LOG_MESSAGE_INFO_INSTALL_PACKAGE_CONFIGURE] =
   {
-    "cdebootstrap/progress/info/install/unpack_package",
+    "cdebootstrap/progress/info/install/package/configure",
+    1,
+    DO_PROGRESS_INFO,
+  },
+  [LOG_MESSAGE_INFO_INSTALL_PACKAGE_EXTRACT] =
+  {
+    "cdebootstrap/progress/info/install/package/extract",
+    1,
+    DO_PROGRESS_INFO,
+  },
+  [LOG_MESSAGE_INFO_INSTALL_PACKAGE_UNPACK] =
+  {
+    "cdebootstrap/progress/info/install/package/unpack",
     1,
     DO_PROGRESS_INFO,
   },
