@@ -18,25 +18,28 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * $LastChangedBy: bastian $
- * $LastChangedDate: 2004-06-06 12:33:27 +0200 (Sun, 06 Jun 2004) $
- * $LastChangedRevision: 429 $
+ * $LastChangedDate: 2005-01-05 22:48:37 +0100 (Mi, 05 Jan 2005) $
+ * $LastChangedRevision: 785 $
  */
 
 #include <config.h>
 
 #include "download.h"
+#include "execute.h"
 #include "frontend.h"
 #include "install.h"
 #include "log.h"
-#include "prepare.h"
 #include "suite.h"
 
+#include <debian-installer.h>
+
 #include <getopt.h>
 #include <libgen.h>
 #include <limits.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <stdarg.h>
+#include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -69,6 +72,7 @@ static struct option const long_opts[] =
   {"debug", no_argument, 0, GETOPT_DEBUG},
   {"download-only", no_argument, 0, 'd'},
   {"flavour", required_argument, 0, 'f'},
+  {"helperdir", required_argument, 0, 'H'},
   {"include", required_argument, 0, 'i'},
   {"quiet", no_argument, 0, 'q'},
   {"verbose", no_argument, 0, 'v'},
@@ -88,7 +92,7 @@ int frontend_download (const char *source, const char *target)
     snprintf (buf, 1024, "wget -q -O %s %s/%s", target, mirror, source);
   else if (!strncmp (mirror, "file://", 7))
     snprintf (buf, 1024, "cp %s/%s %s", mirror + sizeof ("file://") - 1, source, target);
-  ret = install_execute (buf);
+  ret = execute (buf);
 
   return WEXITSTATUS (ret);
 }
@@ -123,6 +127,7 @@ Mandatory arguments to long options are mandatory for short options too.\n\
       --debug                  enable debug\n\
   -d, --download-only          download packages, but don't perform installation\n\
   -f, --flavour=FLAVOUR        select the flavour to use\n\
+  -H, --helperdir=DIR          set the helper directory\n\
   -q, --quiet                  be quiet\n\
   -v, --verbose                be verbose\n\
   -h, --help                   display this help and exit\n\
@@ -141,17 +146,17 @@ DEB_ARCH
   exit (status);
 }
 
-int frontend_main (int argc, char **argv)
+int frontend_main (int argc, char **argv, char **envp)
 {
   int c;
-  char *arch = NULL, *configdir = default_configdir, *flavour = default_flavour, *suite = NULL, *target = NULL;
+  char *arch = NULL, *configdir = default_configdir, *flavour = default_flavour, *helperdir = default_configdir, *suite = NULL, *target = NULL;
   bool download_only = false;
   const char **include = NULL;
   unsigned int include_len = 0, include_size = 0;
 
   program_name = argv[0];
 
-  while ((c = getopt_long (argc, argv, "a:c:df:hi:qv", long_opts, NULL)) != -1)
+  while ((c = getopt_long (argc, argv, "a:c:df:hH:i:qv", long_opts, NULL)) != -1)
   {
     switch (c)
     {
@@ -172,6 +177,9 @@ int frontend_main (int argc, char **argv)
       case 'h':
         usage (EXIT_SUCCESS);
         break;
+      case 'H':
+        helperdir = optarg;
+        break;
       case 'i':
         {
           if (include_size <= include_len || include_size == 0)
@@ -258,13 +266,10 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
   di_init (basename (program_name));
 
   if (check_mirror ())
-    return 1;
+    log_text (DI_LOG_LEVEL_ERROR, "invalid mirror");
 
   if (!download_only && getuid ())
-  {
-    fprintf (stderr, "%s: need root privileges\n", program_name);
-    usage (EXIT_FAILURE);
-  }
+    log_text (DI_LOG_LEVEL_ERROR, "need root privileges");
 
   log_init ();
 
@@ -272,9 +277,11 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
     log_text (DI_LOG_LEVEL_ERROR, "target check");
   if (suite_init (suite, arch, flavour, include, include_len, configdir))
     log_text (DI_LOG_LEVEL_ERROR, "suite init");
+  if (execute_init (envp))
+    log_text (DI_LOG_LEVEL_ERROR, "execute init");
   if (download_init ())
     log_text (DI_LOG_LEVEL_ERROR, "download init");
-  if (!download_only && install_init ())
+  if (!download_only && install_init (helperdir))
     log_text (DI_LOG_LEVEL_ERROR, "install init");
   if (backend_main (download_only))
     log_text (DI_LOG_LEVEL_ERROR, "backend");
