@@ -18,20 +18,12 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * $LastChangedBy: bastian $
- * $LastChangedDate: 2004-06-06 12:33:27 +0200 (Sun, 06 Jun 2004) $
- * $LastChangedRevision: 429 $
+ * $LastChangedDate: 2005-01-22 13:18:17 +0100 (Sa, 22 Jan 2005) $
+ * $LastChangedRevision: 811 $
  */
 
 #include <config.h>
 
-#include "download.h"
-#include "frontend.h"
-#include "install.h"
-#include "log.h"
-#include "packages.h"
-#include "prepare.h"
-#include "suite.h"
-
 #include <limits.h>
 #include <stdlib.h>
 #include <string.h>
@@ -40,14 +32,19 @@
 #include <sys/mount.h>
 #include <unistd.h>
 
-char install_root[PATH_MAX];
-static int count, count_done;
+#include "download.h"
+#include "execute.h"
+#include "frontend.h"
+#include "install.h"
+#include "log.h"
+#include "packages.h"
+#include "prepare.h"
+#include "suite.h"
 
-const char *const environment[] = {
-  "DEBIAN_FRONTEND=noninteractive",
-  "PATH=/usr/bin:/bin:/usr/sbin:/sbin",
-  NULL
-};
+char install_root[PATH_MAX];
+const char *helperdir;
+
+static int count, count_done;
 
 #define BUFSIZE_command 4096
 
@@ -88,13 +85,13 @@ static int install_execute_progress_io_handler (const char *buf, size_t n __attr
   if (sscanf (buf, "Unpacking replacement %128s", buf_package) == 1 ||
       sscanf (buf, "Unpacking %128s", buf_package) == 1)
   {
-    log_message (LOG_MESSAGE_INFO_INSTALL_UNPACK_PACKAGE, buf_package);
+    log_message (LOG_MESSAGE_INFO_INSTALL_PACKAGE_UNPACK, buf_package);
     install_progress_set (++count_done);
     install_execute_progress_update (packages, buf_package, di_package_status_unpacked);
   }
   else if (sscanf (buf, "Setting up %128s", buf_package) == 1)
   {
-    log_message (LOG_MESSAGE_INFO_INSTALL_CONFIGURE_PACKAGE, buf_package);
+    log_message (LOG_MESSAGE_INFO_INSTALL_PACKAGE_CONFIGURE, buf_package);
     install_progress_set (++count_done);
     install_execute_progress_update (packages, buf_package, di_package_status_installed);
   }
@@ -102,36 +99,9 @@ static int install_execute_progress_io_handler (const char *buf, size_t n __attr
   return 0;
 }
 
-static int install_execute_shell (const char *const cmd, di_io_handler *stdout_handler, di_io_handler *stderr_handler, void *io_user_data, di_process_handler *child_prepare_handler, void *child_prepare_user_data)
-{
-  const char *const argv[] = { "sh", "-c", cmd, NULL };
-  int ret = di_exec_env_full ("/bin/sh", argv, environment, stdout_handler, stderr_handler, io_user_data, NULL, NULL, child_prepare_handler, child_prepare_user_data);
-  log_text (DI_LOG_LEVEL_DEBUG, "Return code: %d", ret);
-  return ret;
-}
-
-int install_execute (const char *command)
-{
-  log_text (DI_LOG_LEVEL_DEBUG, "Execute \"%s\"", command);
-  return install_execute_shell (command, install_execute_io_handler, install_execute_io_handler, NULL, NULL, NULL);
-}
-
-static int install_execute_target (const char *command)
-{
-  log_text (DI_LOG_LEVEL_DEBUG, "Execute \"%s\" in chroot", command);
-  return install_execute_shell (command, install_execute_io_handler, install_execute_io_handler, NULL, di_exec_prepare_chroot, install_root);
-}
-
-int install_execute_target_do (const char *command)
-{
-  log_text (DI_LOG_LEVEL_MESSAGE, "Doing something important");
-  return install_execute_target (command);
-}
-
 static int install_execute_target_progress (const char *command, di_packages *packages)
 {
-  log_text (DI_LOG_LEVEL_DEBUG, "Execute \"%s\" in chroot", command);
-  return install_execute_shell (command, install_execute_progress_io_handler, install_execute_io_handler, packages, di_exec_prepare_chroot, install_root);
+  return execute_target_full (command, install_execute_progress_io_handler, install_execute_io_handler, packages);
 }
 
 di_slist *install_list (di_packages *packages, di_packages_allocator *allocator, di_slist *install, di_package_priority priority, di_package_status status)
@@ -213,22 +183,6 @@ di_slist *install_list_package_only (di_packages *packages, char *package, di_pa
   return list;
 }
 
-static int install_apt_cleanup_script (const char *name)
-{
-  char buf[PATH_MAX];
-
-  snprintf (buf, sizeof (buf), "%s/%s", install_root, name);
-
-  if (unlink (buf))
-    return 1;
-
-  snprintf (buf, sizeof (buf), "dpkg-divert --remove --rename %s", name);
-
-  if (install_execute_target (buf))
-    return 1;
-  return 0;
-}
-
 int install_apt_cleanup (void)
 {
   char buf[PATH_MAX];
@@ -239,13 +193,9 @@ int install_apt_cleanup (void)
   if (unlink (buf))
     return 1;
 
-  if (install_apt_cleanup_script ("/usr/sbin/invoke-rc.d") ||
-      install_apt_cleanup_script ("/sbin/start-stop-daemon"))
-    return 1;
-
   strcpy (buf, "apt-get clean");
 
-  if (install_execute_target (buf))
+  if (execute_target (buf))
     return 1;
 
   return 0;
@@ -278,27 +228,6 @@ int install_apt_install (di_packages *packages, di_slist *install)
   return 0;
 }
 
-static int install_apt_prepare_script (const char *name)
-{
-  char buf[PATH_MAX];
-  FILE *out;
-
-  snprintf (buf, sizeof (buf), "%s/%s.REAL", install_root, name);
-
-  unlink (buf);
-
-  snprintf (buf, sizeof (buf), "dpkg-divert --add --local --rename --divert %s.REAL %s", name, name);
-
-  if (install_execute_target (buf))
-    return 1;
-
-  snprintf (buf, sizeof (buf), "%s/%s", install_root, name);
-
-  if (!(out = fopen (buf, "w")) || !fputs ("#!/bin/sh\n", out) || fchmod (fileno (out), 0755) || fclose (out))
-    return 1;
-  return 0;
-}
-
 int install_apt_prepare (void)
 {
   char buf[PATH_MAX];
@@ -317,10 +246,6 @@ int install_apt_prepare (void)
   if (fclose (out))
     return 1;
 
-  if (install_apt_prepare_script ("/usr/sbin/invoke-rc.d") ||
-      install_apt_prepare_script ("/sbin/start-stop-daemon"))
-    return 1;
-
   return 0;
 }
 
@@ -353,7 +278,6 @@ int install_dev_cleanup (void)
   if (0)
   {
     install_dev_opt (buf, "/dev/null", 0, 0, 0);
-    install_dev_opt (buf, "/dev/.devfsd", 0, 0, 0);
   }
   return 0;
 }
@@ -366,8 +290,6 @@ int install_dev_prepare (void)
 
   mask = umask (0);
   ret |= install_dev_opt (buf, "/dev/null", S_IFCHR | 0666, makedev (1, 3), 1);
-  if (0)
-    ret |= install_dev_opt (buf, "/dev/.devfsd", S_IFCHR | 0600, makedev (8, 0), 1);
   umask (mask);
   return ret;
 }
@@ -431,16 +353,6 @@ int install_dpkg_unpack (di_packages *packages, di_slist *install)
   return install_dpkg_all (buf, sizeof (buf), packages, install);
 }
 
-static int install_extract_file (const char *file)
-{
-  char buf_file[PATH_MAX];
-  char buf[PATH_MAX];
-
-  build_target_deb (buf_file, PATH_MAX, file);
-  snprintf (buf, PATH_MAX, "ar -p %s data.tar.gz | tar -xzf -", buf_file);
-  return install_execute (buf);
-}
-
 int install_extract (di_slist *install)
 {
   int count = 0, count_done = 0;
@@ -453,7 +365,7 @@ int install_extract (di_slist *install)
   {
     di_package *p = node->data;
     log_text (DI_LOG_LEVEL_MESSAGE, "Extracting %s", p->package);
-    install_extract_file (package_get_local_filename (p));
+    package_extract (p);
     count_done++;
     frontend_progress_set (((float) count_done/count) * 50 + 450);
   }
@@ -510,8 +422,10 @@ int install_target_check (const char *target)
   return 0;
 }
 
-int install_init (void)
+int install_init (const char *_helperdir)
 {
+  helperdir = _helperdir;
+
   if (prepare_install ())
     return 1;
   log_open ();
@@ -556,3 +470,52 @@ void install_umount (void)
   }
 }
 
+int install_helper_execute (const char *command)
+{
+  log_message (LOG_MESSAGE_INFO_INSTALL_HELPER_EXECUTE);
+  return execute_target (command);
+}
+
+int install_helper_install (const char *name)
+{
+  char package[128];
+  char file_source[512];
+  char file_dest[512];
+  char buf[1024];
+  int ret;
+  struct stat s;
+
+  log_message (LOG_MESSAGE_INFO_INSTALL_HELPER_INSTALL, name);
+
+  snprintf (package, sizeof (package), "%s.deb", name);
+
+  snprintf (file_source, sizeof (file_source), "%s/%s", helperdir, package);
+  snprintf (file_dest, sizeof (file_source), "%s/%s", install_root, package);
+
+  if (stat (file_source, &s) < 0)
+    log_text (DI_LOG_LEVEL_ERROR, "Helper package %s not found.", name);
+
+  snprintf (buf, sizeof (buf), "cp %s %s", file_source, file_dest);
+  ret = execute (buf);
+  if (ret)
+    return ret;
+
+  snprintf (buf, sizeof (buf), "dpkg -i /%s", package);
+  ret = execute_target (buf);
+  unlink (file_dest);
+
+  return ret;
+}
+
+int install_helper_remove (const char *name)
+{
+  char buf[128];
+
+  log_message (LOG_MESSAGE_INFO_INSTALL_HELPER_REMOVE, name);
+
+  snprintf (buf, sizeof (buf), "dpkg -P %s", name);
+  execute_target (buf);
+
+  return 0;
+}
+
