@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * $LastChangedBy: bastian $
- * $LastChangedDate: 2004-06-06 12:33:27 +0200 (Sun, 06 Jun 2004) $
- * $LastChangedRevision: 429 $
+ * $LastChangedDate: 2004-09-09 20:00:10 +0200 (Do, 09 Sep 2004) $
+ * $LastChangedRevision: 624 $
  */
 
 #include <config.h>
@@ -43,37 +43,62 @@ static const char **include;
 static unsigned int include_size;
 const char *configdir = NULL;
 
-static void suite_init_check_sections (void *key __attribute__ ((unused)), void *data, void *user_data)
+static void suite_init_check_action (suite_config_action *action)
+{
+  di_slist_node *node;
+
+  if (action->flavour.head)
+    for (node = action->flavour.head; node; node = node->next)
+    {
+      if (!strcasecmp (flavour, node->data))
+      {
+        action->activate = true;
+        break;
+      }
+    }
+  else
+    action->activate = true;
+}
+
+static void suite_init_check_section (void *key __attribute__ ((unused)), void *data, void *user_data)
 {
   suite_config *config = user_data;
   suite_config_section *section = data;
   di_slist_node *node1, *node2;
 
-  for (node1 = section->flavour.head; node1; node1 = node1->next)
-  {
-    if (!config->flavour_valid &&
-        !strcasecmp (flavour, node1->data))
-      config->flavour_valid = true;
-    if (!strcasecmp ("any", node1->data) ||
-        !strcasecmp (flavour, node1->data))
+  if (section->flavour.head)
+    for (node1 = section->flavour.head; node1; node1 = node1->next)
     {
-      section->activate = true;
-      break;
+      if (!config->flavour_valid &&
+          !strcasecmp (flavour, node1->data))
+        config->flavour_valid = true;
+      if (!strcasecmp ("any", node1->data) ||
+          !strcasecmp (flavour, node1->data))
+      {
+        section->activate = true;
+        break;
+      }
     }
-  }
+  else
+    section->activate = true;
 
   if (section->activate)
     for (node1 = section->packages.head; node1; node1 = node1->next)
     {
       suite_config_packages *packages = node1->data;
 
-      for (node2 = packages->arch.head; node2; node2 = node2->next)
-        if (!strcasecmp ("any", node2->data) ||
-            !strcasecmp (arch, node2->data))
-        {
-          packages->activate = true;
-          break;
-        }
+      if (packages->arch.head)
+      {
+        for (node2 = packages->arch.head; node2; node2 = node2->next)
+          if (!strcasecmp ("any", node2->data) ||
+              !strcasecmp (arch, node2->data))
+          {
+            packages->activate = true;
+            break;
+          }
+      }
+      else
+        packages->activate = true;
     }
 }
 
@@ -107,10 +132,14 @@ int suite_init_second (const char *_suite_name)
 
 static int suite_check (void)
 {
+  di_slist_node *node;
+
   if (!strncmp ("minimal", flavour, sizeof ("minimal") - 1))
     suite->flavour_valid = true;
 
-  di_hash_table_foreach (suite->sections, suite_init_check_sections, suite);
+  for (node = suite->actions.head; node; node = node->next)
+    suite_init_check_action (node->data);
+  di_hash_table_foreach (suite->sections, suite_init_check_section, suite);
 
   if (!suite->flavour_valid)
     log_text (DI_LOG_LEVEL_ERROR, "Unknown flavour %s", flavour);
