@@ -18,12 +18,13 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * $LastChangedBy: bastian $
- * $LastChangedDate: 2004-06-06 12:33:27 +0200 (Sun, 06 Jun 2004) $
- * $LastChangedRevision: 429 $
+ * $LastChangedDate: 2005-01-14 22:34:27 +0100 (Fr, 14 Jan 2005) $
+ * $LastChangedRevision: 806 $
  */
 
 #include <config.h>
 
+#include "execute.h"
 #include "frontend.h"
 #include "install.h"
 #include "packages.h"
@@ -40,7 +41,7 @@ typedef int suite_install_action (suite_config_action *action, int data, di_pack
 
 static int action_execute (suite_config_action *action, int data __attribute__ ((unused)), di_packages *packages __attribute__ ((unused)), di_packages_allocator *allocator __attribute__ ((unused)), di_slist *install __attribute__ ((unused)))
 {
-  return install_execute_target_do (action->what);
+  return install_helper_execute (action->what);
 }
 
 static di_package_priority action_check_priority (const char *text)
@@ -127,6 +128,24 @@ static int action_install (suite_config_action *action, int _data, di_packages *
   return 0;
 }
 
+enum action_helper
+{
+  ACTION_HELPER_INSTALL,
+  ACTION_HELPER_REMOVE,
+};
+
+static int action_helper (suite_config_action *action __attribute__ ((unused)), int data, di_packages *packages __attribute__ ((unused)), di_packages_allocator *allocator __attribute__ ((unused)), di_slist *install __attribute__ ((unused)))
+{
+  switch (data)
+  {
+    case ACTION_HELPER_INSTALL:
+      return install_helper_install (action->what);
+    case ACTION_HELPER_REMOVE:
+      return install_helper_remove (action->what);
+  };
+  return 0;
+}
+
 static int action_mount (suite_config_action *action __attribute__ ((unused)), int data __attribute__ ((unused)), di_packages *packages __attribute__ ((unused)), di_packages_allocator *allocator __attribute__ ((unused)), di_slist *install __attribute__ ((unused)))
 {
   if (install_mount_proc ())
@@ -177,6 +196,8 @@ suite_install_actions[] =
   { "dpkg-unpack", action_install, ACTION_INSTALL_DPKG_UNPACK },
   { "execute", action_execute, 0 },
   { "extract", action_install, ACTION_INSTALL_EXTRACT },
+  { "helper-install", action_helper, ACTION_HELPER_INSTALL },
+  { "helper-remove", action_helper, ACTION_HELPER_REMOVE },
   { "mount", action_mount, 0 },
   { NULL, NULL, 0 },
 };
@@ -190,6 +211,9 @@ int suite_action (di_packages *packages, di_packages_allocator *allocator, di_sl
   {
     suite_config_action *e = node->data;
 
+    if (!e->activate)
+      continue;
+
     for (action = suite_install_actions; action->name; action++)
       if (!strcasecmp (action->name, e->action))
         break;
